<?php
namespace Bushelpowered\Api\Data\Analytics\V1\Response;
        
class ContractResponse 
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $displayId The contract id typically used by end users*/
    public string $displayId;
    /** @var string $accountId The account identifier.*/
    public string $accountId;
    /** @var null|string $commodityId The commodity identifier.*/
    public ?string $commodityId = null;
    /** @var null|string $locationId The location identifier.*/
    public ?string $locationId = null;
    /** @var null|float $sourceQuantityContracted The quantity of contracted units. Commonly stipulates the total units to be delivered. Quantities typically increment by fixed amounts, such as per 5000 bu.*/
    public ?float $sourceQuantityContracted = null;
    /** @var null|float $sourceQuantityCanceled The quantity of canceled units. Units may be canceled for a number of business reasons which are not captured by this field. Though it is common for a closed contract to have some small quantity canceled due to qualitative adjustments applied to gross quantities delivered.*/
    public ?float $sourceQuantityCanceled = null;
    /** @var null|float $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this contract.*/
    public ?float $sourceQuantityDelivered = null;
    /** @var null|string $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.*/
    public ?string $sourceQuantityUom = null;
    /** @var null|bool $sourceIsClosed Flag indicating the overall status of the contract. Generally, we'd prefer to capture the nuance of possible business statues, but it is otherwise advantageous to know when a contract is closed for certain applications of the data, such as displaying to the grower.*/
    public ?bool $sourceIsClosed = null;
    /** @var null|string $sourceCropYear The crop year of the contract's commodity. Often a year span indicating growing season.*/
    public ?string $sourceCropYear = null;
    /** @var string $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var \Bushelpowered\Api\Data\Analytics\V1\Response\PricingLineResponse[] $pricingLines */
    public array $pricingLines;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $displayId The contract id typically used by end users
     * @param  string  $accountId The account identifier.
     * @param  null|string  $commodityId The commodity identifier.
     * @param  null|string  $locationId The location identifier.
     * @param  null|float  $sourceQuantityContracted The quantity of contracted units. Commonly stipulates the total units to be delivered. Quantities typically increment by fixed amounts, such as per 5000 bu.
     * @param  null|float  $sourceQuantityCanceled The quantity of canceled units. Units may be canceled for a number of business reasons which are not captured by this field. Though it is common for a closed contract to have some small quantity canceled due to qualitative adjustments applied to gross quantities delivered.
     * @param  null|float  $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this contract.
     * @param  null|string  $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.
     * @param  null|bool  $sourceIsClosed Flag indicating the overall status of the contract. Generally, we'd prefer to capture the nuance of possible business statues, but it is otherwise advantageous to know when a contract is closed for certain applications of the data, such as displaying to the grower.
     * @param  null|string  $sourceCropYear The crop year of the contract's commodity. Often a year span indicating growing season.
     * @param  string  $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  \Bushelpowered\Api\Data\Analytics\V1\Response\PricingLineResponse[]  $pricingLines 
     */
    public function __construct(string $id, string $tenantId, string $displayId, string $accountId, ?string $commodityId, ?string $locationId, ?float $sourceQuantityContracted, ?float $sourceQuantityCanceled, ?float $sourceQuantityDelivered, ?string $sourceQuantityUom, ?bool $sourceIsClosed, ?string $sourceCropYear, string $sourceCreatedAt, array $pricingLines)
    {
        $this->id = $id;
        $this->tenantId = $tenantId;
        $this->displayId = $displayId;
        $this->accountId = $accountId;
        $this->commodityId = $commodityId;
        $this->locationId = $locationId;
        $this->sourceQuantityContracted = $sourceQuantityContracted;
        $this->sourceQuantityCanceled = $sourceQuantityCanceled;
        $this->sourceQuantityDelivered = $sourceQuantityDelivered;
        $this->sourceQuantityUom = $sourceQuantityUom;
        $this->sourceIsClosed = $sourceIsClosed;
        $this->sourceCropYear = $sourceCropYear;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->pricingLines = $pricingLines;
    }
    

}