<?php
namespace Bushelpowered\Api\Grain\Contracts\V1\Model;
        
class PricingLineRaw implements \Bushelpowered\Api\Common\Event\RawRecord, \Bushelpowered\Api\Common\HasSourceTimestamps
{
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var null|string $sourceLocationId The source location identifier.*/
    public ?string $sourceLocationId = null;
    /** @var null|string $locationIntegrationId The location integration identifier.*/
    public ?string $locationIntegrationId = null;
    /** @var string $sourceContractId The source contract identifier.*/
    public string $sourceContractId;
    /** @var string $contractIntegrationId The contract integration identifier.*/
    public string $contractIntegrationId;
    /** @var null|float $sourceBasisPrice The basis price, which is an adjustment to the future price offsetting costs incurred by the buyer.*/
    public ?float $sourceBasisPrice = null;
    /** @var null|float $sourceCashPrice The cash price, which is the maximum value per unit the seller can receive.*/
    public ?float $sourceCashPrice = null;
    /** @var null|string $sourceCurrency The currency in which the contract is transacted.*/
    public ?string $sourceCurrency = null;
    /** @var null|string $sourceDeliveryPeriodStart The delivery period start date. Delivery periods are derived from futures months and, generally, start along with calendar months. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeliveryPeriodStart = null;
    /** @var null|string $sourceDeliveryPeriodEnd The delivery period end date. Delivery periods are derived from futures months and, generally, end along with calendar months. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeliveryPeriodEnd = null;
    /** @var null|string $sourceDeliveryStatus Some value defining the current delivery status. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unfilled/Filled.*/
    public ?string $sourceDeliveryStatus = null;
    /** @var null|string $sourceDisplayId The grower-friendly identifier for the pricing line. Growers are typically only ever exposed to a single identifier which is often a small part of a larger, unique, compound-identifier. Notwithstanding, this ID is vital for applications of the data which are intended to primarily be understood by humans.*/
    public ?string $sourceDisplayId = null;
    /** @var null|string $sourceFuturesMonth The future month, or the month during which a commodity would be brought to market.*/
    public ?string $sourceFuturesMonth = null;
    /** @var null|float $sourceFuturesPrice The future price, which is the month-specific market rate for a commodity.*/
    public ?float $sourceFuturesPrice = null;
    /** @var null|string $sourcePricedAt The date-time when pricing was applied, v.v. optional. Repeatedly considered removing it. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourcePricedAt = null;
    /** @var null|string $sourcePricingStatus Some value defining whether a contract is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unpriced/Priced.*/
    public ?string $sourcePricingStatus = null;
    /** @var null|float $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this pricing line.*/
    public ?float $sourceQuantityDelivered = null;
    /** @var null|float $sourceQuantityPriced The quantity of priced units.*/
    public ?float $sourceQuantityPriced = null;
    /** @var null|string $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.*/
    public ?string $sourceQuantityUom = null;
    /** @var null|float $sourceEstimatedAdditionalAdjustment The estimated additional adjustments on the contracts that are not priced yet. This can be, or is typically, used with OTC/option contracts to display the adjustment value at present time for bushels not priced.*/
    public ?float $sourceEstimatedAdditionalAdjustment = null;
    /** @var null|float $sourceEstimatedFutures The estimated futures price of the bushels remaining on contract that do not have a futures price.*/
    public ?float $sourceEstimatedFutures = null;
    /** @var null|float $sourceAdjustment The total priced adjustments for a contract, whether they are fees, premiums, freight or other.*/
    public ?float $sourceAdjustment = null;
    /** @var null|int $sourceSequenceNumber The source-defined ordinality of a pricing line.*/
    public ?int $sourceSequenceNumber = null;
    /** @var null|string $sourceSignatureStatus Some value defining whether a pricing line is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unsigned/Signed.*/
    public ?string $sourceSignatureStatus = null;
    /** @var null|string $sourceComments Additional comments about the contract. Occasionally, about the grower... Seriously, these values may not be intended to be shown to some consumers!*/
    public ?string $sourceComments = null;
    /** @var null|\Bushelpowered\Api\Grain\Contracts\V1\Model\PricingHistorySyncWrapper $pricingHistories */
    public ?\Bushelpowered\Api\Grain\Contracts\V1\Model\PricingHistorySyncWrapper $pricingHistories = null;
    /** @var null|string $sourceAccountId The datasource's remote id of the account that owns this record, if any.*/
    public ?string $sourceAccountId = null;
    /** @var string $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var string $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var null|string $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  null|string  $sourceLocationId The source location identifier.
     * @param  null|string  $locationIntegrationId The location integration identifier.
     * @param  string  $sourceContractId The source contract identifier.
     * @param  string  $contractIntegrationId The contract integration identifier.
     * @param  null|float  $sourceBasisPrice The basis price, which is an adjustment to the future price offsetting costs incurred by the buyer.
     * @param  null|float  $sourceCashPrice The cash price, which is the maximum value per unit the seller can receive.
     * @param  null|string  $sourceCurrency The currency in which the contract is transacted.
     * @param  null|string  $sourceDeliveryPeriodStart The delivery period start date. Delivery periods are derived from futures months and, generally, start along with calendar months. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeliveryPeriodEnd The delivery period end date. Delivery periods are derived from futures months and, generally, end along with calendar months. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeliveryStatus Some value defining the current delivery status. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unfilled/Filled.
     * @param  null|string  $sourceDisplayId The grower-friendly identifier for the pricing line. Growers are typically only ever exposed to a single identifier which is often a small part of a larger, unique, compound-identifier. Notwithstanding, this ID is vital for applications of the data which are intended to primarily be understood by humans.
     * @param  null|string  $sourceFuturesMonth The future month, or the month during which a commodity would be brought to market.
     * @param  null|float  $sourceFuturesPrice The future price, which is the month-specific market rate for a commodity.
     * @param  null|string  $sourcePricedAt The date-time when pricing was applied, v.v. optional. Repeatedly considered removing it. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourcePricingStatus Some value defining whether a contract is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unpriced/Priced.
     * @param  null|float  $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this pricing line.
     * @param  null|float  $sourceQuantityPriced The quantity of priced units.
     * @param  null|string  $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.
     * @param  null|float  $sourceEstimatedAdditionalAdjustment The estimated additional adjustments on the contracts that are not priced yet. This can be, or is typically, used with OTC/option contracts to display the adjustment value at present time for bushels not priced.
     * @param  null|float  $sourceEstimatedFutures The estimated futures price of the bushels remaining on contract that do not have a futures price.
     * @param  null|float  $sourceAdjustment The total priced adjustments for a contract, whether they are fees, premiums, freight or other.
     * @param  null|int  $sourceSequenceNumber The source-defined ordinality of a pricing line.
     * @param  null|string  $sourceSignatureStatus Some value defining whether a pricing line is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unsigned/Signed.
     * @param  null|string  $sourceComments Additional comments about the contract. Occasionally, about the grower... Seriously, these values may not be intended to be shown to some consumers!
     * @param  null|\Bushelpowered\Api\Grain\Contracts\V1\Model\PricingHistorySyncWrapper  $pricingHistories 
     * @param  null|string  $sourceAccountId The datasource's remote id of the account that owns this record, if any.
     * @param  string  $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourceLocationId, ?string $locationIntegrationId, string $sourceContractId, string $contractIntegrationId, ?float $sourceBasisPrice, ?float $sourceCashPrice, ?string $sourceCurrency, ?string $sourceDeliveryPeriodStart, ?string $sourceDeliveryPeriodEnd, ?string $sourceDeliveryStatus, ?string $sourceDisplayId, ?string $sourceFuturesMonth, ?float $sourceFuturesPrice, ?string $sourcePricedAt, ?string $sourcePricingStatus, ?float $sourceQuantityDelivered, ?float $sourceQuantityPriced, ?string $sourceQuantityUom, ?float $sourceEstimatedAdditionalAdjustment, ?float $sourceEstimatedFutures, ?float $sourceAdjustment, ?int $sourceSequenceNumber, ?string $sourceSignatureStatus, ?string $sourceComments, ?\Bushelpowered\Api\Grain\Contracts\V1\Model\PricingHistorySyncWrapper $pricingHistories, ?string $sourceAccountId, string $sourceUpdatedAt, string $sourceCreatedAt, ?string $sourceDeletedAt)
    {
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceLocationId = $sourceLocationId;
        $this->locationIntegrationId = $locationIntegrationId;
        $this->sourceContractId = $sourceContractId;
        $this->contractIntegrationId = $contractIntegrationId;
        $this->sourceBasisPrice = $sourceBasisPrice;
        $this->sourceCashPrice = $sourceCashPrice;
        $this->sourceCurrency = $sourceCurrency;
        $this->sourceDeliveryPeriodStart = $sourceDeliveryPeriodStart;
        $this->sourceDeliveryPeriodEnd = $sourceDeliveryPeriodEnd;
        $this->sourceDeliveryStatus = $sourceDeliveryStatus;
        $this->sourceDisplayId = $sourceDisplayId;
        $this->sourceFuturesMonth = $sourceFuturesMonth;
        $this->sourceFuturesPrice = $sourceFuturesPrice;
        $this->sourcePricedAt = $sourcePricedAt;
        $this->sourcePricingStatus = $sourcePricingStatus;
        $this->sourceQuantityDelivered = $sourceQuantityDelivered;
        $this->sourceQuantityPriced = $sourceQuantityPriced;
        $this->sourceQuantityUom = $sourceQuantityUom;
        $this->sourceEstimatedAdditionalAdjustment = $sourceEstimatedAdditionalAdjustment;
        $this->sourceEstimatedFutures = $sourceEstimatedFutures;
        $this->sourceAdjustment = $sourceAdjustment;
        $this->sourceSequenceNumber = $sourceSequenceNumber;
        $this->sourceSignatureStatus = $sourceSignatureStatus;
        $this->sourceComments = $sourceComments;
        $this->pricingHistories = $pricingHistories;
        $this->sourceAccountId = $sourceAccountId;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The source location identifier.
     */
    public function getSourceLocationId(): ?string
    {
        return $this->sourceLocationId;
    }
    /**
     * @return null|string The datasource's remote id of the account that owns this record, if any.
     */
    public function getSourceAccountId(): ?string
    {
        return $this->sourceAccountId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}