<?php
namespace Bushelpowered\Api\Payments\V1\Model;
        
class PaymentDetail 
{
    /** @var string $id */
    public string $id;
    /** @var string $item A human readable name that will briefly describe this payment*/
    public string $item;
    /** @var string $amount The amount of this payment*/
    public string $amount;
    /** @var \Bushelpowered\Api\Payments\V1\Enums\PaymentStatus $status */
    public \Bushelpowered\Api\Payments\V1\Enums\PaymentStatus $status;
    /** @var null|string $comments The person making the payment can say anything that they want to about the payment. Required for one time payments*/
    public ?string $comments = null;
    /** @var string $counterPartyUserName The party on the other side of the transaction.*/
    public string $counterPartyUserName;
    /** @var string $paymentMethod The payment method of the payment.*/
    public string $paymentMethod;
    /** @var null|string $processedAt When the payment process was started of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $processedAt = null;
    /** @var null|string $completedAt When the payment process was completed of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $completedAt = null;
    /** @var string $updatedAt When the payment was last updated of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var \Bushelpowered\Api\Payments\V1\Model\SettlementAttachment[] $settlements Attached settlements*/
    public array $settlements;
    /** @var \Bushelpowered\Api\Payments\V1\Model\InvoiceAttachment[] $invoices Attached invoices*/
    public array $invoices;
    /** @var \Bushelpowered\Api\Payments\V1\Model\PaymentDetailTotalLineItem[] $totalLineItems An itemized list of objects that could go in the subtotal*/
    public array $totalLineItems;

    /**
     * @param  string  $id 
     * @param  string  $item A human readable name that will briefly describe this payment
     * @param  string  $amount The amount of this payment
     * @param  \Bushelpowered\Api\Payments\V1\Enums\PaymentStatus  $status 
     * @param  null|string  $comments The person making the payment can say anything that they want to about the payment. Required for one time payments
     * @param  string  $counterPartyUserName The party on the other side of the transaction.
     * @param  string  $paymentMethod The payment method of the payment.
     * @param  null|string  $processedAt When the payment process was started of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $completedAt When the payment process was completed of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt When the payment was last updated of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  \Bushelpowered\Api\Payments\V1\Model\SettlementAttachment[]  $settlements Attached settlements
     * @param  \Bushelpowered\Api\Payments\V1\Model\InvoiceAttachment[]  $invoices Attached invoices
     * @param  \Bushelpowered\Api\Payments\V1\Model\PaymentDetailTotalLineItem[]  $totalLineItems An itemized list of objects that could go in the subtotal
     */
    public function __construct(string $id, string $item, string $amount, \Bushelpowered\Api\Payments\V1\Enums\PaymentStatus $status, ?string $comments, string $counterPartyUserName, string $paymentMethod, ?string $processedAt, ?string $completedAt, string $updatedAt, array $settlements, array $invoices, array $totalLineItems)
    {
        $this->id = $id;
        $this->item = $item;
        $this->amount = $amount;
        $this->status = $status;
        $this->comments = $comments;
        $this->counterPartyUserName = $counterPartyUserName;
        $this->paymentMethod = $paymentMethod;
        $this->processedAt = $processedAt;
        $this->completedAt = $completedAt;
        $this->updatedAt = $updatedAt;
        $this->settlements = $settlements;
        $this->invoices = $invoices;
        $this->totalLineItems = $totalLineItems;
    }
    

}