<?php
namespace Bushelpowered\Api\Quoting\V1\Response;
        
class FileImportListItemResponse implements \Bushelpowered\Api\Common\HasCreatedBy, \Bushelpowered\Api\Common\HasCreatedAtTimestamp
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $name Name of the file as it was stored on the computer that uploaded it*/
    public string $name;
    /** @var null|int $numberOfProducts Number of products that were processed successfully*/
    public ?int $numberOfProducts = null;
    /** @var string[] $processingMessage Brief message on how the processing of the file went. This could be a list of errors.*/
    public array $processingMessage;
    /** @var \Bushelpowered\Api\Quoting\V1\Enums\ProcessingResultStatus $status */
    public \Bushelpowered\Api\Quoting\V1\Enums\ProcessingResultStatus $status;
    /** @var string $createdBy Created by UUID within the microservice.*/
    public string $createdBy;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $name Name of the file as it was stored on the computer that uploaded it
     * @param  null|int  $numberOfProducts Number of products that were processed successfully
     * @param  string[]  $processingMessage Brief message on how the processing of the file went. This could be a list of errors.
     * @param  \Bushelpowered\Api\Quoting\V1\Enums\ProcessingResultStatus  $status 
     * @param  string  $createdBy Created by UUID within the microservice.
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $name, ?int $numberOfProducts, array $processingMessage, \Bushelpowered\Api\Quoting\V1\Enums\ProcessingResultStatus $status, string $createdBy, string $createdAt)
    {
        $this->id = $id;
        $this->name = $name;
        $this->numberOfProducts = $numberOfProducts;
        $this->processingMessage = $processingMessage;
        $this->status = $status;
        $this->createdBy = $createdBy;
        $this->createdAt = $createdAt;
    }
    
    /**
     * @return string Created by UUID within the microservice.
     */
    public function getCreatedBy(): string
    {
        return $this->createdBy;
    }
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
}