<?php
namespace Bushelpowered\Api\Statement\V1\Model;
        
class StatementRaw implements \Bushelpowered\Api\Common\Event\RawRecord, \Bushelpowered\Api\Common\HasSourceTimestamps
{
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var string $sourceAccountId The source account identifier.*/
    public string $sourceAccountId;
    /** @var string $accountIntegrationId The account integration identifier.*/
    public string $accountIntegrationId;
    /** @var string $sourceCurrency The currency associated with the balances coming from the datasource e.g. USD, CAD.*/
    public string $sourceCurrency;
    /** @var float $sourceTotalBalance The total financial obligation reported for this time period.*/
    public float $sourceTotalBalance;
    /** @var float $sourceBalanceDue The immediate financial obligation reported for the time report.*/
    public float $sourceBalanceDue;
    /** @var string $sourceIssueDate The date the statement was issued to the customer. of yyyy-MM-dd format, IE: 2023-10-04*/
    public string $sourceIssueDate;
    /** @var null|string $sourceDueDate The date the statement’s balance is due. of yyyy-MM-dd format, IE: 2023-10-04*/
    public ?string $sourceDueDate = null;
    /** @var null|string $sourceStatus The status for the statement received.*/
    public ?string $sourceStatus = null;
    /** @var null|string $sourceLocationId The datasource's remote id of the location that owns this record, if any.*/
    public ?string $sourceLocationId = null;
    /** @var string $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var string $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var null|string $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  string  $sourceAccountId The source account identifier.
     * @param  string  $accountIntegrationId The account integration identifier.
     * @param  string  $sourceCurrency The currency associated with the balances coming from the datasource e.g. USD, CAD.
     * @param  float  $sourceTotalBalance The total financial obligation reported for this time period.
     * @param  float  $sourceBalanceDue The immediate financial obligation reported for the time report.
     * @param  string  $sourceIssueDate The date the statement was issued to the customer. of yyyy-MM-dd format, IE: 2023-10-04
     * @param  null|string  $sourceDueDate The date the statement’s balance is due. of yyyy-MM-dd format, IE: 2023-10-04
     * @param  null|string  $sourceStatus The status for the statement received.
     * @param  null|string  $sourceLocationId The datasource's remote id of the location that owns this record, if any.
     * @param  string  $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $tenantId, string $datasourceId, string $integrationId, string $sourceId, string $sourceAccountId, string $accountIntegrationId, string $sourceCurrency, float $sourceTotalBalance, float $sourceBalanceDue, string $sourceIssueDate, ?string $sourceDueDate, ?string $sourceStatus, ?string $sourceLocationId, string $sourceUpdatedAt, string $sourceCreatedAt, ?string $sourceDeletedAt)
    {
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceAccountId = $sourceAccountId;
        $this->accountIntegrationId = $accountIntegrationId;
        $this->sourceCurrency = $sourceCurrency;
        $this->sourceTotalBalance = $sourceTotalBalance;
        $this->sourceBalanceDue = $sourceBalanceDue;
        $this->sourceIssueDate = $sourceIssueDate;
        $this->sourceDueDate = $sourceDueDate;
        $this->sourceStatus = $sourceStatus;
        $this->sourceLocationId = $sourceLocationId;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return string The source account identifier.
     */
    public function getSourceAccountId(): string
    {
        return $this->sourceAccountId;
    }
    /**
     * @return null|string The datasource's remote id of the location that owns this record, if any.
     */
    public function getSourceLocationId(): ?string
    {
        return $this->sourceLocationId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}